"""
false

Does nothing except return a status code of 1.
"""

def main(*args):
    return 1
